@@ -18,14 +18,17 @@ lazy_static! {
             ("ALICE/USDT", 0.1_f64),
             ("ALPHA/USDT", 1_f64),
             ("ANKR/USDT", 1_f64),
+            ("ARPA/USDT", 1_f64),
             ("ATA/USDT", 1_f64),
             ("ATOM/USDT", 0.1_f64),
+            ("AUDIO/USDT", 1_f64),
             ("AVAX/USDT", 0.1_f64),
             ("AXS/USDT", 1_f64),
             ("BAL/USDT", 0.1_f64),
             ("BAND/USDT", 0.1_f64),
             ("BAT/USDT", 1_f64),
             ("BCH/USDT", 0.01_f64),
+            ("BIT/USDT", 1_f64),
             ("BNB/USDT", 0.01_f64),
             ("BP/USDT", 0.1_f64),
             ("BSV/USDT", 0.01_f64),
@@ -33,8 +36,11 @@ lazy_static! {
             ("BTM/USDT", 10_f64),
             ("BTS/USDT", 1_f64),
             ("BTT/USDT", 1_f64),
+            ("BZZ/USDT", 0.1_f64),
             ("C98/USDT", 1_f64),
+            ("CELO/USDT", 1_f64),
             ("CELR/USDT", 1_f64),
+            ("CFX/USDT", 1_f64),
             ("CHZ/USDT", 1_f64),
             ("COMP/USDT", 0.01_f64),
             ("COTI/USDT", 1_f64),
@@ -47,6 +53,7 @@ lazy_static! {
             ("DGB/USDT", 1_f64),
             ("DOGE/USDT", 100_f64),
             ("DOT/USDT", 0.1_f64),
+            ("DYDX/USDT", 1_f64),
             ("EGLD/USDT", 0.1_f64),
             ("ENJ/USDT", 1_f64),
             ("EOS/USDT", 0.1_f64),
@@ -55,7 +62,10 @@ lazy_static! {
             ("FILECOIN/USDT", 0.01_f64),
             ("FLM/USDT", 1_f64),
             ("FLOW/USDT", 0.1_f64),
+            ("FODL/USDT", 1_f64),
+            ("FTM/USDT", 1_f64),
             ("FTT/USDT", 0.1_f64),
+            ("GALA/USDT", 10_f64),
             ("GRT/USDT", 1_f64),
             ("GTC/USDT", 0.1_f64),
             ("HBAR/USDT", 1_f64),
@@ -68,6 +78,8 @@ lazy_static! {
             ("IOTA/USDT", 1_f64),
             ("IOTX/USDT", 1_f64),
             ("KAVA/USDT", 0.1_f64),
+            ("KEEP/USDT", 1_f64),
+            ("KLAY/USDT", 1_f64),
             ("KNC/USDT", 0.1_f64),
             ("KSM/USDT", 0.01_f64),
             ("LINA/USDT", 1_f64),
@@ -79,6 +91,7 @@ lazy_static! {
             ("MANA/USDT", 1_f64),
             ("MASK/USDT", 0.1_f64),
             ("MATIC/USDT", 1_f64),
+            ("MINA/USDT", 1_f64),
             ("MKR/USDT", 0.01_f64),
             ("MTL/USDT", 1_f64),
             ("NEAR/USDT", 1_f64),
@@ -93,6 +106,8 @@ lazy_static! {
             ("ONT/USDT", 1_f64),
             ("QTUM/USDT", 0.1_f64),
             ("RACA/USDT", 1000_f64),
+            ("RAY/USDT", 0.1_f64),
+            ("REEF/USDT", 1_f64),
             ("RSR/USDT", 1_f64),
             ("SAND/USDT", 1_f64),
             ("SC/USDT", 1_f64),
@@ -114,6 +129,7 @@ lazy_static! {
             ("UNI/USDT", 0.1_f64),
             ("VET/USDT", 1_f64),
             ("WAVES/USDT", 0.1_f64),
+            ("XCH/USDT", 0.01_f64),
             ("XEM/USDT", 1_f64),
             ("XLM/USDT", 10_f64),
             ("XMR/USDT", 0.01_f64),
@@ -160,7 +176,7 @@ fn fetch_linear_contract_sizes() -> BTreeMap<String, f64> {
 
     let mut mapping: BTreeMap<String, f64> = BTreeMap::new();
 
-    if let Ok(txt) = http_get("https://contract.mxc.com/api/v1/contract/detail") {
+    if let Ok(txt) = http_get("https://contract.mexc.com/api/v1/contract/detail") {
         if let Ok(resp) = serde_json::from_str::<ResponseMsg>(&txt) {
             for linear_market in resp.data.iter().filter(|x| x.settleCoin == x.quoteCoin) {
                 mapping.insert(
